<?php
/**
 * A general menu system class
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007 - 2009 Roland Haeder, this is free software
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
class BaseMenu extends BaseFrameworkSystem {
	/**
	 * Protected constructor
	 *
	 * @param	$className	Name of the class
	 * @return	void
	 */
	protected function __construct ($className) {
		// Call parent constructor
		parent::__construct($className);
	}

	/**
	 * Renders the menu by loading the base template and a menu-specific
	 * template.
	 *
	 * @return	void
	 */
	public function renderMenu () {
		// Initialize the menu system by preparing it's template instance
		$templateInstance = ObjectFactory::createObjectByConfiguredName('menu_template_class', array($this));

		// Set it for later use
		$this->setTemplateInstance($templateInstance);

		// Load the menu template for all
		$this->getTemplateInstance()->loadMenuTemplate('generic_menu_entries');

		// Get the 'page' from request instance
		$page = $this->getApplicationInstance()->getRequestInstance()->getRequestElement('page');

		// Load the menu template for this page
		try {
			$this->getTemplateInstance()->loadMenuTemplate($page . '_menu_entries');
		} catch (FileIoException $e) {
			// @TODO Should we log it here? We should, because it will be silently ignored.
		}

		// Get the prepared content
		$menuContent = $this->getTemplateInstance()->getRawTemplateData();

		// Render it here
		$this->getTemplateInstance()->renderXmlContent($menuContent);
		//exit(__METHOD__ . ':!OK');
	}

	/**
	 * Transfers the rendered menu to a given templatex engine by assigning
	 * the rendered content with a template variable.
	 *
	 * @param	$templateInstance	An instance of a CompileableTemplate class
	 * @return	void
	 */
	public function transferContentToTemplateEngine (CompileableTemplate $templateInstance) {
		$this->partialStub('templateInstance=' . $templateInstance->__toString());
	}
}

// [EOF]
?>
